``sunkit-image``
================

|Latest Version| |codecov| |Powered by NumFOCUS| |Powered by Sunpy|

.. |Powered by Sunpy| image:: http://img.shields.io/badge/powered%20by-SunPy-orange.svg?style=flat
   :target: https://www.sunpy.org
.. |Latest Version| image:: https://img.shields.io/pypi/v/sunkit-image.svg
   :target: https://pypi.python.org/pypi/sunkit-image/
.. |codecov| image:: https://codecov.io/gh/sunpy/sunpy/branch/main/graph/badge.svg
   :target: https://codecov.io/gh/sunpy/sunkit-image
.. |Powered by NumFOCUS| image:: https://img.shields.io/badge/powered%20by-NumFOCUS-orange.svg?style=flat&colorA=E1523D&colorB=007D8A
   :target: http://numfocus.org

``sunkit-image`` is a a open-source toolbox for solar physics image processing.
Currently it is an experimental library for solar physics specific image processing routines.
Ideally it will only contain routines that have been published in the literature.

See `sunkit-image Documentation`_ for instructions on how to install and contribute.

Usage of Generative AI
----------------------

We expect authentic engagement in our community.
Be wary of posting output from Large Language Models or similar generative AI as comments on GitHub or any other platform, as such comments tend to be formulaic and low quality content.
If you use generative AI tools as an aid in developing code or documentation changes, ensure that you fully understand the proposed changes and can explain why they are the correct approach and an improvement to the current state.

Code of Conduct
---------------

When you are interacting with the SunPy community you are asked to follow our `code of conduct <https://sunpy.org/coc>`__.

.. _sunkit-image Documentation: https://docs.sunpy.org/projects/sunkit-image/en/stable/
